Class: BottleRocket::Generators::InstallGenerator
- Inherits:
-
Rails::Generators::Base
- Object
- Rails::Generators::Base
- BottleRocket::Generators::InstallGenerator
- Defined in:
- lib/generators/bottle_rocket/install/install_generator.rb,
lib/generators/bottle_rocket/install/install_generator.rb
Instance Method Summary collapse
Instance Method Details
#copy ⇒ Object
11 12 13 14 |
# File 'lib/generators/bottle_rocket/install/install_generator.rb', line 11 def copy say_status('copying', 'countdown', :green) copy_file 'countdown.js', 'public/javascripts/countdown.js' end |
#do_nothing ⇒ Object
24 25 26 27 28 |
# File 'lib/generators/bottle_rocket/install/install_generator.rb', line 24 def do_nothing say_status('deprecated', 'You are using Rails 3.1 with the asset pipeline enabled, so this generator is not needed.') say_status('', 'The necessary files are already in your asset pipeline.') say_status('', 'Just add `//= require countdown` to your app/assets/javascripts/application.js') end |